@@ -42,7 +42,7 @@ def in_section(
         assert response, 'Response is required.'
 
         response_json = await response.json()
-        if response_json or section not in response_json:
+        if not response_json or section not in response_json:
             return False
 
         section_text = json.dumps(response_json[section])
